@@ -15,6 +15,9 @@ METHODS = [GET, HEAD, POST, PUT, PATCH, CONNECT, TRACE, DELETE, OPTIONS]
 
 MESSAGE_NOT_FOUND = 'Not found'
 
+SHUTDOWN = 'shutdown'
+STARTUP = 'startup'
+
 STATUS_OK = OK = 200
 STATUS_CREATED = CREATED = 201
 STATUS_NOT_FOUND = NOT_FOUND = 404
